@@ -4,13 +4,13 @@ use warnings;
 
 use Carp qw(croak);
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 require XSLoader;
 XSLoader::load('RPi::DHT11', $VERSION);
 
 sub new {
-    my ($class, $pin) = @_;
+    my ($class, $pin, $debug) = @_;
 
     croak "you must supply a pin number\n" if ! defined $pin;
 
@@ -19,6 +19,10 @@ sub new {
 
     setup();
 
+    defined $debug
+        ? c_debug($debug)
+        : c_debug(0);
+
     return $self;
 }
 sub temp {
@@ -87,7 +91,7 @@ at the command line).
 
 =head1 METHODS
 
-=head2 new($pin)
+=head2 new($pin, $debug)
 
 Parameters:
 
@@ -95,6 +99,10 @@ Parameters:
 
 Mandatory. BCM GPIO pin number for the DHT11 sensor's DATA pin..
 
+    $debug
+
+Optional: Bool. True, C<1> to enable debug output, False, C<0> to disable.
+
 =head2 temp('f')
 
 Fetches the current temperature.
